<?php
/* params is an array:
- dimensions => array(0 => "xxxx", 1 => ...)
- metrics => array(0 => array(expression => "xxxx", alias => "yyyy"), 1 => ...)
- dateRanges => array(0 => array(startDate => "xxxx", endDate => "yyyy"), 1 => ...)
- orderBys => array(FieldName => "xxxx", OrderType => "yyyy", SortOrder => "zzzz")
- pageSize => X (integer)
- filters => array(0 => array(dimensionName => "xxxx", operator => "yyyy", expression => "zzzz"), 1 => ...)
   $html_table will return the results as an html table instead of PHP table
*/
/*
returns an array with each row of the report. Dimensions first and then metrics, in the same order we set them in $params
*/
function get_analytics($params, $html_table = false){
	// Load the Google API PHP Client Library.
	require_once find_in_path("lib/vendor/autoload.php");
	
	$client = new Google_Client();
	$client->setAuthConfig(json_decode(lire_config("google_analytics_api/credentials"),true));
	$client->setAccessType("offline");
  $client->setApprovalPrompt("force");
  $client->setAccessToken(lire_config("google_analytics_api/token"));
	$client->addScope(Google_Service_Analytics::ANALYTICS_READONLY);
	
	if($client->isAccessTokenExpired()){ 
    $refresh_token = lire_config("google_analytics_api/refresh_token");
    $client->fetchAccessTokenWithRefreshToken($refresh_token);
    $accessToken = $client->getAccessToken();
    $accessToken["refresh_token"] = $refresh_token;
    //file_put_contents(CLIENT_CREDENTIALS_PATH, json_encode($accessToken));
    ecrire_config("google_analytics_api/token", json_encode($accessToken));
    $client->setAccessToken($accessToken);
  }

  if (!$client->getAccessToken()) {
    print("no access token, whaawhaaa");
    exit;
  }
	
	// Create an authorized analytics service object.
  $analytics = new Google_Service_AnalyticsReporting($client);
  // Create the ReportRequest object.
  $request = new Google_Service_AnalyticsReporting_ReportRequest();
  // Replace with your view ID, for example XXXX.
  $view_id = lire_config("google_analytics_api/view_id");
  $request->setViewId($view_id);
  
  // Create the DateRange object.
  if(isset($params["dateRanges"]) && is_array($params["dateRanges"])){
	  $dateRanges = array();
	  foreach($params["dateRanges"] as $dateRange){
		  $dateRange_tmp = new Google_Service_AnalyticsReporting_DateRange();
		  $dateRange_tmp->setStartDate($dateRange["startDate"]);
		  $dateRange_tmp->setEndDate($dateRange["endDate"]);
		  $dateRanges[] = $dateRange_tmp;
		}
		$request->setDateRanges($dateRanges);
	}
	
	//Create the Dimensions object.
	if(isset($params["dimensions"]) && is_array($params["dimensions"])){
		$dimensions_list = array();
		foreach($params["dimensions"] as $dimension){
			$dimension_tmp = new Google_Service_AnalyticsReporting_Dimension();
			$dimension_tmp->setName($dimension);
			$dimensions_list[] = $dimension_tmp;
		}
		$request->setDimensions($dimensions_list);
	}
	
	// Create the Metrics object.
  if(isset($params["metrics"]) && is_array($params["metrics"])){
  	$metrics_list = array();
		foreach($params["metrics"] as $metric){
		  $metric_tmp = new Google_Service_AnalyticsReporting_Metric();
		  $metric_tmp->setExpression($metric["expression"]);
		  $metric_tmp->setAlias($metric["alias"]);
			$metrics_list[] = $metric_tmp;
		}
		$request->setMetrics(array($metrics_list));
	}
	
	// order of results
	if(isset($params["orderBys"]) && is_array($params["orderBys"])){
		$ordering = new Google_Service_AnalyticsReporting_OrderBy();
		$ordering->setFieldName($params["orderBys"]["FieldName"]);
		$ordering->setOrderType($params["orderBys"]["OrderType"]);   
		$ordering->setSortOrder($params["orderBys"]["SortOrder"]);
		$request->setOrderBys($ordering);
  }
  
  // number of rows in result
  if(isset($params["pageSize"]) && is_numeric($params["pageSize"])){
  	$request->setPageSize($params["pageSize"]);
	}
	
	if(isset($params["filters"]) && is_array($params["filters"])){
		$filtersGroup = array();
		$filters = $params["filters"];
	  foreach($filters as $filter){
	      $dimensionFilter = new Google_Service_AnalyticsReporting_DimensionFilter();
	      $dimensionFilter->setDimensionName($filter["dimensionName"]);
	      $dimensionFilter->setOperator($filter["operator"]);
	      $dimensionFilter->setExpressions($filter["expression"]);
	
	      $filter_clause = new Google_Service_AnalyticsReporting_DimensionFilterClause();
	      $filter_clause->setFilters($dimensionFilter);
	      $filtersGroup[] = $filter_clause;
	  }
		$request->setDimensionFilterClauses($filtersGroup);
	}
	
	$body = new Google_Service_AnalyticsReporting_GetReportsRequest();
  $body->setReportRequests(array($request));
  $reports = $analytics->reports->batchGet($body);
  
  // now parse the report into an array. Dimensions first then metrics.
  $result = array();
	$table = "";
	// we only manage one report per API call for now
  $report = $reports[0];
  $header = $report->getColumnHeader();
  $dimensionHeaders = $header->getDimensions();
  $metricHeaders = $header->getMetricHeader()->getMetricHeaderEntries();
  
  $table .= "<table><tr>";
  for ($i = 0; $i < count($dimensionHeaders); $i++) {
   	$table .= "<th>".$dimensionHeaders[$i]."</th>";
  }
  for ($i = 0; $i < count($metricHeaders); $i++) {
   	$table .= "<th>".$metricHeaders[$i]->getName()."</th>";
  }
	$table .= "</tr>";

  $rows = $report->getData()->getRows();

  for($rowIndex = 0; $rowIndex < count($rows); $rowIndex++){
    $row_result = array();
    $row = $rows[$rowIndex];
    $dimensions = $row->getDimensions();   
    $metrics = $row->getMetrics();
    $table .= "<tr>";
    for ($i = 0; $i < count($dimensionHeaders) && $i < count($dimensions); $i++) {
     	$row_result[] = $dimensions[$i];
      $table .= "<td>".$dimensions[$i]."</td>";
    }

    for ($j = 0; $j < count($metrics); $j++) {
      $values = $metrics[$j]->getValues();
      for ($k = 0; $k < count($values); $k++) {
        $entry = $metricHeaders[$k];
        $table .= "<td>".$values[$k]."</td>";
        $row_result[] = $values[$k];
      }
    }
    $table .= "</tr>";
    $result[] = $row_result;
  }
  $table .= "</table>";
  if($html_table) return $table;
  return $result;
}

?>